Pipeline - Qudas 0.1.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# Pipeline

pipelineのフローを操作するためのモジュールです。

class qudas.pipeline.Pipeline(steps: Sequence[Tuple[str, Any]], iterator: IteratorMixin | None = None)

  Bases: `object`

  fit(X: Any, y: Any | None = None) → Pipeline

    各ステップを順に適用してデータを訓練する。

    Parameters:

      - X (Any) – 入力データ。

      - y (Any) – ターゲットデータ。

    Returns:

      パイプラインオブジェクト自身。

    Return type:

      Pipeline

    Raises:

      RuntimeError – 最後のステップに fit メソッドがない場合。

  get_global_params() → Dict[str, Any]

    パイプライン全体に適用されたグローバルパラメータを取得する。

    Returns:

      グローバルパラメータ。

    Return type:

      Dict[str, Any]

  get_models() → Dict[str, Any]

    学習されたモデルを取得する。

    Returns:

      各ステップごとのモデル。

    Return type:

      Dict[str, Any]

  get_results() → Dict[str, Any]

    最適化結果を取得する。

    Returns:

      各ステップごとの最適化結果。

    Return type:

      Dict[str, Any]

  optimize(X: Any | None = None, y: Any | None = None) → Dict[str, Any]

    各ステップを順に適用して最適化を実行する。

    Parameters:

      - X (Any) – 入力データ。

      - y (Any) – ターゲットデータ。

    Returns:

      各ステップの最適化結果。

    Return type:

      Dict[str, Any]

    Raises:

      RuntimeError – 最後のステップに optimize メソッドがない場合。

  predict(X: Any | None = None) → Dict[str, Any]

    各ステップを順に適用してデータを予測する。予測を行うためには、最後のステップで IteratorMixin でないステップが predict メソッドを持っている必要がある。

    Parameters:

      X (Any) – 入力データ。

    Returns:

      予測結果。

    Return type:

      Any

    Raises:

      RuntimeError – 最後のステップに predict メソッドがない場合。最後のステップで model が作成されていない場合。

  set_global_params(params: Dict[str, Any]) → None

    パイプライン全体に適用するグローバルパラメータを設定する。

    Parameters:

      params (Dict[str, Any]) – グローバルパラメータ。

Contents:

- BaseStep
  - `BaseStep`
- IteratorMixin
  - `IteratorMixin`
- OptimizerMixin
  - `OptimizerMixin`